<?php

namespace ahrefs\AhrefsSeo\Workers;

use ahrefs\AhrefsSeo\Ahrefs_Seo;
use ahrefs\AhrefsSeo\Ahrefs_Seo_Errors;
use ahrefs\AhrefsSeo\Ahrefs_Seo_Compatibility;
use ahrefs\AhrefsSeo\Ahrefs_Seo_Noindex;
use ahrefs\AhrefsSeo\Messages\Message;
use ahrefs\AhrefsSeo\Post_Tax;
/**
 * Worker_Noindex class.
 * Load is noindex details.
 *
 * @since 0.7.3
 */
class Worker_Noindex extends Worker {

	const API_NAME       = 'noindex';
	const WHAT_TO_UPDATE = 'isnoindex';
	/**
	 * @var int Load up to 2 pages in same request.
	 */
	protected $items_at_once = 2;
	/** @var float Delay after successful request to API */
	protected $pause_after_success = 1;
	/**
	 * Run update for items in list
	 *
	 * @param Post_Tax[] $post_taxes Post ID list.
	 * @return bool False if rate limit error received and need to do pause.
	 */
	protected function update_posts( array $post_taxes ) {
		$this->update_posts_info( $post_taxes );
		return ! $this->has_rate_error;
	}
	/**
	 * Update post with the is noindex.
	 *
	 * @param Post_Tax[] $post_taxes What to update.
	 *
	 * @return void
	 */
	public function update_posts_info( array $post_taxes ) {
		$page_id_to_url_list = [];
		foreach ( $post_taxes as $post_tax ) {
			$url = $post_tax->get_url();
			if ( '' !== $url ) {
				$page_id_to_url_list[ (string) $post_tax ] = $url;
			} else {
				$this->content_audit->update_noindex_values( $post_tax, -1 ); // set error.
			}
		}
		if ( is_null( $this->api ) || ! $this->api instanceof Ahrefs_Seo_Noindex ) {
			$this->api = new Ahrefs_Seo_Noindex();
		}
		$results = $this->api->is_noindex( $page_id_to_url_list );
		$this->update_noindex_values( $results );
	}
	/**
	 * Update noindex values using results
	 *
	 * @param array $results Associave array page_tax_string => int: 0 - index, 1 - noindex, -1 - error.
	 * @return void
	 */
	protected function update_noindex_values( array $results ) {
		Ahrefs_Seo::breadcrumbs( sprintf( '%s: %s', __METHOD__, wp_json_encode( $results ) ) );
		foreach ( $results as $post_tax_string => $is_noindex ) {
			try {
				$post_tax = Post_Tax::create_from_string( "{$post_tax_string}" );
				$this->content_audit->update_noindex_values( $post_tax, (int) $is_noindex );
			} catch ( \Error $e ) {
				$error = Ahrefs_Seo_Compatibility::on_type_error( $e, __METHOD__, __FILE__, __( 'Update "is noindex" info failed.', 'ahrefs-seo' ) );
			} catch ( \Exception $e ) {
				Ahrefs_Seo::notify( $e, 'Update "is noindex" info failed.' );
				Ahrefs_Seo_Errors::save_message( 'noindex', __( 'Update "is noindex" info failed.', 'ahrefs-seo' ), Message::TYPE_NOTICE );
			}
		}
	}
}
