<?php
/**
 * Content header template
 */

declare(strict_types=1);
namespace ahrefs\AhrefsSeo;

$locals = Ahrefs_Seo_View::get_template_variables();
// link to the Content Settings.
$link          = add_query_arg(
	[
		'page'   => Ahrefs_Seo::SLUG_SETTINGS,
		'tab'    => Ahrefs_Seo_Screen_Settings::TAB_CONTENT,
		'return' => add_query_arg( 'page', Ahrefs_Seo::SLUG_CONTENT, admin_url( 'admin.php' ) ),
	],
	admin_url( 'admin.php' )
);
$stat          = Ahrefs_Seo_Data_Content::get()->get_statictics();
$can_run_audit = Ahrefs_Seo_Data_Content::get()->can_run_new_audit();
$paused        = Content_Audit::audit_is_paused();
?>
<div id="ahrefs_seo_screen" class="<?php echo isset( $locals['header_class'] ) ? esc_attr( '' . implode( ' ', $locals['header_class'] ) ) : ''; ?>">

<div class="ahrefs-header-wrap">
	<div class="ahrefs-header">

		<div>
			<img src="<?php echo esc_attr( AHREFS_SEO_IMAGES_URL . 'logo-content-audit.svg' ); ?>" class="logo">
			<span class="header-hint"><?php echo esc_html( $stat['last_time'] ); ?></span>
		</div>
		<div class="content-right">
			<div>
				<a class="content-hint-support" href="<?php echo esc_attr( Ahrefs_Seo::get_support_url() ); ?>" target="_blank"><span class="dashicons dashicons-email"></span><?php esc_html_e( 'Support', 'ahrefs-seo' ); ?></a>
			</div>
			<div>
				<a class="content-hint-how" href="https://help.ahrefs.com/en/articles/3901720-how-does-the-ahrefs-seo-wordpress-plugin-work" target="_blank"> <?php esc_html_e( 'How it works', 'ahrefs-seo' ); ?></a>
			</div>
			<div id="content_audit_status" class="<?php echo esc_attr( $stat['in_progress'] ? 'in-progress' : '' ); ?><?php echo esc_attr( $paused ? ' paused' : '' ); ?>">
				<a
					class="run-audit-button button-orange manual-update-content-link<?php if ( ! $can_run_audit ) { ?> disabled<?php } // phpcs:ignore Squiz.ControlStructures.ControlSignature.NewlineAfterOpenBrace ?>"
					href="#">
					<?php
					/* Translators: Button title at the header, must be short */
					echo esc_html_x( 'Run new audit', 'button title', 'ahrefs-seo' );
					?>
					</a>
				<a
					class="paused-audit-button button-dark <?php if ( ! $can_run_audit ) { ?> disabled<?php } // phpcs:ignore Squiz.ControlStructures.ControlSignature.NewlineAfterOpenBrace ?>"
					href="#">
					<?php
					/* Translators: Button title at the header, must be short */
					echo esc_html_x( 'Resume audit', 'button title', 'ahrefs-seo' );
					?>
					</a>
				<div class="audit-progressbar">
					<div class="position"
						<?php if ( $stat['percents'] > 0 ) { ?> style="width:<?php echo esc_attr( $stat['percents'] . '%' ); // phpcs:ignore Squiz.ControlStructures.ControlSignature.NewlineAfterOpenBrace ?>"<?php } ?>>
					</div>
					<div class="progress">
					<?php
					/* Translators: Button title at the header, must be short */
					echo esc_html_x( 'Analyzing...', 'button title', 'ahrefs-seo' );
					?>
					</div>
				</div>
			</div>
			<div>
				<a id="analysis_setting_button" class="button" href="<?php echo esc_attr( $link ); ?>"></a>
			</div>
		</div>
	</div>
</div>
