<?php
declare(strict_types=1);
namespace ahrefs\AhrefsSeo;

$locals   = Ahrefs_Seo_View::get_template_variables();
$view     = Ahrefs_Seo::get()->get_view();
$post_tax = $locals['post_tax'];

$backlinks = Ahrefs_Seo_Data_Content::get()->content_get_backlinks_for_post( $post_tax );
?>
<div class="more-wrap">
	<div class="more-column-performance">
		<div class="column-title"><?php esc_html_e( 'Performance', 'ahrefs-seo' ); ?></div>
		<?php
		$view->show_part(
			'action-parts/pages-performance',
			[
				'position'       => 20,
				'unique-keyword' => false,
				'backlinks'      => $backlinks,
			]
		);
		?>
	</div>
	<div class="more-column-action">
		<div class="column-title"><?php esc_html_e( 'Recommended action', 'ahrefs-seo' ); ?></div>
		<ol>
			<li>
				<p><?php esc_html_e( 'Consolidate', 'ahrefs-seo' ); ?></p>
				<p><?php esc_html_e( 'There are other articles on your blog targeting the same topic as this one. We suggest consolidating the content from all similar articles into the best performing one.', 'ahrefs-seo' ); ?></p>

				<?php
				$items = Ahrefs_Seo_Advisor::get()->find_relevant_top_performing_pages( $post_tax, 3 );
				if ( ! is_null( $items ) ) {
					/* translators: %d: number of pages */
					$subtitle = sprintf( _n( '%d Top-performing page on the same topic', '%d Top-performing pages on the same topic', count( $items ), 'ahrefs-seo' ), count( $items ) ); // @phpcs:ignore WordPress.WP.I18n.MissingSingularPlaceholder
					$view->show_part(
						'action-parts/pages-list',
						[
							'items'    => $items,
							'subtitle' => $subtitle,
						]
					);
				}
				$items = Ahrefs_Seo_Advisor::get()->find_relevant_under_performing_pages( $post_tax, 100 );
				if ( ! is_null( $items ) ) {
					/* translators: %d: number of pages */
					$subtitle = sprintf( _n( '%d underperforming page that can be merged with the top-performing one', '%d underperforming pages that can be merged with the top-performing one', count( $items ), 'ahrefs-seo' ), count( $items ) );
					$view->show_part(
						'action-parts/pages-list',
						[
							'items'    => $items,
							'subtitle' => $subtitle,
						]
					);
				}
				?>
			</li>
			<li>
				<p><?php esc_html_e( 'Republish the post', 'ahrefs-seo' ); ?></p>
				<p><?php esc_html_e( 'Change the publish or updated date of your article to the current date. This lets Google know that your content is fresh.', 'ahrefs-seo' ); ?></p>
			</li>
			<li>
				<p><?php esc_html_e( 'Merge', 'ahrefs-seo' ); ?></p>
				<p><?php esc_html_e( 'Add 301 redirects from poor performing articles to the republished one.', 'ahrefs-seo' ); ?></p>
				<p><a class="link-small" href="https://ahrefs.com/blog/301-redirects/" target="_blank"><?php esc_html_e( 'How to add 301 redirects', 'ahrefs-seo' ); ?> <span class="arrow-right">→</span></a></p>
			</li>
		</ol>

	</div>
</div>
