<?php
declare(strict_types=1);
namespace ahrefs\AhrefsSeo;

$locals   = Ahrefs_Seo_View::get_template_variables();
$view     = Ahrefs_Seo::get()->get_view();
$post_tax = $locals['post_tax'];

$backlinks         = Ahrefs_Seo_Data_Content::get()->content_get_backlinks_for_post( $post_tax );
$advisor           = Ahrefs_Seo_Advisor::get();
$has_keyword       = $advisor->has_keyword( $post_tax );
$is_keyword_unique = ! $advisor->has_active_pages_with_same_keywords( $post_tax );
?>
<div class="more-wrap">
	<div class="more-column-performance">
		<div class="column-title"><?php esc_html_e( 'Performance', 'ahrefs-seo' ); ?></div>
		<?php
		$view->show_part(
			'action-parts/pages-performance',
			[
				'position'       => 20,
				'unique-keyword' => $has_keyword && $is_keyword_unique,
				'backlinks'      => $backlinks,
			]
		);
		?>
	</div>
	<div class="more-column-action">
		<div class="column-title"><?php esc_html_e( 'Recommended action', 'ahrefs-seo' ); ?></div>
		<ol>
			<?php
			if ( $has_keyword ) {
				?>
			<li>
				<p><?php esc_html_e( 'Match search intent', 'ahrefs-seo' ); ?></p>
				<p><?php esc_html_e( 'This article is targeting a unique topic, but is currently performing poorly. Check the SERPs to see if your post is aligned with your target keyword’s search intent.', 'ahrefs-seo' ); ?></p>
				<p><a class="link-small" href="https://ahrefs.com/blog/search-intent/" target="_blank"><?php esc_html_e( 'How to optimize for search intent', 'ahrefs-seo' ); ?> <span class="arrow-right">→</span></a></p>
			</li>
				<?php
			} else {
				?>
			<li>
				<p><?php esc_html_e( 'Perform keyword research', 'ahrefs-seo' ); ?></p>
				<p><?php esc_html_e( 'We couldn’t detect a keyword with this page. Perform some keyword research to find out how to update this page to rank for some keywords.', 'ahrefs-seo' ); ?></p>
				<p><a class="link-small" href="https://ahrefs.com/blog/keyword-research/" target="_blank"><?php esc_html_e( 'How to perform keyword research', 'ahrefs-seo' ); ?> <span class="arrow-right">→</span></a></p>
			</li>
				<?php
			}
			?>
			<li>
				<p><?php esc_html_e( 'Update', 'ahrefs-seo' ); ?></p>
				<p><?php esc_html_e( 'Optimize your post by rewriting or updating it with new and unique content.', 'ahrefs-seo' ); ?></p>
				<p><a class="link-small" href="https://ahrefs.com/blog/republishing-content/" target="_blank"><?php esc_html_e( 'How to update your content', 'ahrefs-seo' ); ?> <span class="arrow-right">→</span></a></p>
			</li>
			<li>
				<p><?php esc_html_e( 'Republish the post', 'ahrefs-seo' ); ?></p>
				<p><?php esc_html_e( 'When you’ve updated your post with new content, change the publish or updated date of your article to the current date. This lets Google know your content is fresh.', 'ahrefs-seo' ); ?></p>
			</li>
			<li>
				<p><?php esc_html_e( 'Promote the post', 'ahrefs-seo' ); ?></p>
				<p><?php esc_html_e( 'Re-promote the article. You can also consider doing some outreach to get more backlinks.', 'ahrefs-seo' ); ?></p>
				<p><a class="link-small" href="https://www.youtube.com/watch?v=PoVYweKH4ck" target="_blank"><?php esc_html_e( 'Content promotion checklist', 'ahrefs-seo' ); ?> <span class="arrow-right">→</span></a></p>
				<p><a class="link-small" href="https://ahrefs.com/blog/how-to-get-backlinks/" target="_blank"><?php esc_html_e( 'How to get more backlinks', 'ahrefs-seo' ); ?> <span class="arrow-right">→</span></a></p>
			</li>
		</ol>

	</div>
</div>
