<?php
declare(strict_types=1);
namespace ahrefs\AhrefsSeo;

use ahrefs\AhrefsSeo\Disconnect_Reason\Disconnect_Reason_GSC;

$locals    = Ahrefs_Seo_View::get_template_variables();
$view      = Ahrefs_Seo::get()->get_view();
$analytics = Ahrefs_Seo_Analytics::get();
// get ua list and current choice.
$connected         = $analytics->get_data_tokens()->get_ua_id() && $analytics->get_data_tokens()->get_gsc_site();
$incorrect_account = false === $analytics->is_gsc_account_correct() || false === $analytics->is_ga_account_correct();

if ( empty( $locals['button_title'] ) ) {
	$locals['button_title'] = __( 'Continue', 'ahrefs-seo' );
}
?>
<form method="post" action="" class="ahrefs-seo-wizard ahrefs-analytics <?php if ( $incorrect_account ) { ?> gsc-no-account<?php } if ( $locals['preselect_accounts'] ) { ?> autodetect<?php } // phpcs:ignore Squiz.ControlStructures.ControlSignature.NewlineAfterOpenBrace ?>">
	<input type="hidden" name="analytics_step" value="2">
	<?php
	if ( isset( $locals['page_nonce'] ) ) {
		wp_nonce_field( $locals['page_nonce'] );
	}
	?>
	<div class="card-item">
		<div class="help">
			<div class="google-logos">
				<img src="<?php echo esc_attr( AHREFS_SEO_IMAGES_URL . 'google-analytics.svg' ); ?>">
				<img src="<?php echo esc_attr( AHREFS_SEO_IMAGES_URL . 'google-gsc.svg' ); ?>">
			</div>
			<?php esc_html_e( 'Connect your Google Analytics & Search Console accounts to see your pages’ rankings and traffic stats right in WP dashboard. The Content Audit and content suggestion are based on these data.', 'ahrefs-seo' ); ?>
		</div>
		<div class="help">
			<?php echo sprintf( '%s %s ', sprintf( ' <strong>%s</strong>', esc_html__( 'Important.', 'ahrefs-seo' ) ), esc_html__( 'Ahrefs does not store any data from a connected Google Analytics or Google Search Console account.', 'ahrefs-seo' ) ); ?>
		</div>

		<hr class="hr-shadow" />

		<div class="no-account-detected">
			<?php
			$view->show_part( 'options-tips/not-detected', $locals );
			?>
		</div>

		<div class="disconnect-wrap">
			<div class="your-account"><?php esc_html_e( 'Your Google Analytics & Search Console accounts are connected', 'ahrefs-seo' ); ?></div>
			<div class="your-account your-account-detecting"><?php esc_html_e( 'Autoselecting the best Google Analytics & Search Console profiles...', 'ahrefs-seo' ); ?></div>
			<div class="your-account no-account-detected"><?php esc_html_e( 'Your Google account is connected but no suitable profiles were detected', 'ahrefs-seo' ); ?></div>
			<a href="<?php echo esc_attr( $locals['disconnect_link'] ); ?>" class="disconnect-button" id="ahrefs_disconnect"><span class="text"><?php esc_html_e( 'Disconnect', 'ahrefs-seo' ); ?></span></a>
		</div>
		<div class="accounts-wrap">
			<div id="loader_google_detect">
				<div class="row-loader loader-transparent"><div class="loader"></div></div>
			</div>
			<?php
			if ( $locals['preselect_accounts'] ) {
				?>
				<!-- hide accounts loader -->
				<style type="text/css">#loader_while_accounts_loaded{display:none;}</style>
				<?php
			}
			echo '<!-- padding ' . str_pad( '', 10240, ' ' ) . ' -->'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			$view->flush(); // show loader while settings screen is loading.
			$view->show_part( 'options/include/select-ga', $locals );
			$view->show_part( 'options/include/select-gsc', $locals );
			?>
		</div>
	</div>
	<?php

	// block with error messages, if any happened.
	$messages         = Ahrefs_Seo_Errors::get_current_messages();
	$gsc_disconnected = ( new Disconnect_Reason_GSC() )->get_reason();
	if ( $messages ) {
		$view->show_part( 'messages', [ 'messages' => $messages ] );
		?>
		<script type="text/javascript">
			jQuery('h1').after( jQuery('.ahrefs_messages_block').detach() );
		</script>
		<?php
	}
	if ( ! is_null( $gsc_disconnected ) ) {
		$gsc_disconnected->show();
		?>
		<script type="text/javascript">
			jQuery('h1').after( jQuery('.tip-google').detach() );
		</script>
		<?php
	}
	?>
	<div class="button-wrap">
		<a href="#" class="button button-hero button-primary" id="ahrefs_seo_submit" <?php disabled( ! $connected ); ?>><?php echo esc_html( $locals['button_title'] ); ?></a>
	</div>
</form>
<?php
if ( $locals['preselect_accounts'] ) {
	?>
	<script type="text/javascript">
		console.log('autodetect google');
		jQuery(function() {
			ahrefs_settings.autodetect();
		});
	</script>
	<?php
}
